@@ -83,7 +83,7 @@ struct _EContentEditorInterface {
 							 const gchar *uri);
 
 	void		(*insert_emoticon)		(EContentEditor *editor,
-							 EEmoticon *emoticon);
+							 const EEmoticon *emoticon);
 
 	void		(*move_caret_on_coordinates)	(EContentEditor *editor,
 							 gint x,
@@ -144,7 +144,7 @@ struct _EContentEditorInterface {
 
 	gchar *		(*insert_signature)		(EContentEditor *editor,
 							 const gchar *content,
-							 gboolean is_html,
+							 EContentEditorMode editor_mode,
 							 gboolean can_reposition_caret,
 							 const gchar *signature_id,
 							 gboolean *set_signature_from_message,
@@ -251,12 +251,14 @@ struct _EContentEditorInterface {
 	gchar *		(*image_get_align)		(EContentEditor *editor);
 
 	void		(*link_get_properties)		(EContentEditor *editor,
-							 gchar **href,
-							 gchar **text);
+							 gchar **out_href,
+							 gchar **out_text,
+							 gchar **out_name);
 
 	void		(*link_set_properties)		(EContentEditor *editor,
 							 const gchar *href,
-							 const gchar *text);
+							 const gchar *text,
+							 const gchar *name);
 
 	void		(*page_set_text_color)		(EContentEditor *editor,
 							 const GdkRGBA *value);
@@ -422,12 +424,32 @@ struct _EContentEditorInterface {
 	void		(*content_changed)		(EContentEditor *editor);
 	CamelMimePart *	(*ref_mime_part)		(EContentEditor *editor,
 							 const gchar *uri);
+
+	void		(*delete_h_rule)		(EContentEditor *editor);
+	void		(*delete_image)			(EContentEditor *editor);
+
+	gboolean	(*supports_mode)		(EContentEditor *editor,
+							 EContentEditorMode mode);
+	void		(*grab_focus)			(EContentEditor *editor);
+	gboolean	(*is_focus)			(EContentEditor *editor);
+	const gchar *	(*get_hover_uri)		(EContentEditor *editor);
+	void		(*get_caret_client_rect)	(EContentEditor *editor,
+							 GdkRectangle *out_rect);
+	gdouble		(*get_zoom_level)		(EContentEditor *editor);
+	void		(*set_zoom_level)		(EContentEditor *editor,
+							 gdouble level);
+	/* padding for future expansion */
+	gpointer reserved[13];
 };
 
 /* Properties */
 
 ESpellChecker *	e_content_editor_ref_spell_checker
 						(EContentEditor *editor);
+gboolean	e_content_editor_supports_mode	(EContentEditor *editor,
+						 EContentEditorMode mode);
+void		e_content_editor_grab_focus	(EContentEditor *editor);
+gboolean	e_content_editor_is_focus	(EContentEditor *editor);
 gboolean	e_content_editor_is_malfunction	(EContentEditor *editor);
 gboolean	e_content_editor_can_cut	(EContentEditor *editor);
 gboolean	e_content_editor_can_copy	(EContentEditor *editor);
@@ -446,9 +468,6 @@ void		e_content_editor_set_editable	(EContentEditor *editor,
 gboolean	e_content_editor_get_changed	(EContentEditor *editor);
 void		e_content_editor_set_changed	(EContentEditor *editor,
 						 gboolean changed);
-gboolean	e_content_editor_get_html_mode	(EContentEditor *editor);
-void		e_content_editor_set_html_mode	(EContentEditor *editor,
-						 gboolean html_mode);
 void		e_content_editor_set_alignment	(EContentEditor *editor,
 						 EContentEditorAlignment value);
 EContentEditorAlignment
@@ -567,10 +586,9 @@ CamelMimePart *	e_content_editor_util_create_data_mimepart
 
 void		e_content_editor_insert_image	(EContentEditor *editor,
 						 const gchar *uri);
-
 void		e_content_editor_insert_emoticon
 						(EContentEditor *editor,
-						 EEmoticon *emoticon);
+						 const EEmoticon *emoticon);
 
 void		e_content_editor_move_caret_on_coordinates
 						(EContentEditor *editor,
@@ -644,7 +662,7 @@ void		e_content_editor_take_last_error(EContentEditor *editor,
 gchar *		e_content_editor_insert_signature
 						(EContentEditor *editor,
 						 const gchar *content,
-						 gboolean is_html,
+						 EContentEditorMode editor_mode,
 						 gboolean can_reposition_caret,
 						 const gchar *signature_id,
 						 gboolean *set_signature_from_message,
@@ -779,13 +797,15 @@ void		e_content_editor_image_set_height_follow
 
 void		e_content_editor_link_get_properties
 						(EContentEditor *editor,
-						 gchar **href,
-						 gchar **text);
+						 gchar **out_href,
+						 gchar **out_text,
+						 gchar **out_name);
 
 void		e_content_editor_link_set_properties
 						(EContentEditor *editor,
 						 const gchar *href,
-						 const gchar *text);
+						 const gchar *text,
+						 const gchar *name);
 
 void		e_content_editor_page_set_text_color
 						(EContentEditor *editor,
@@ -977,6 +997,16 @@ void		e_content_editor_spell_check_replace_all
 						(EContentEditor *editor,
 						 const gchar *word,
 						 const gchar *replacement);
+void		e_content_editor_delete_h_rule	(EContentEditor *editor);
+void		e_content_editor_delete_image	(EContentEditor *editor);
+
+const gchar *	e_content_editor_get_hover_uri	(EContentEditor *editor);
+void		e_content_editor_get_caret_client_rect
+						(EContentEditor *editor,
+						 GdkRectangle *out_rect);
+gdouble		e_content_editor_get_zoom_level	(EContentEditor *editor);
+void		e_content_editor_set_zoom_level	(EContentEditor *editor,
+						 gdouble level);
 
 /* Signal helpers */
 
@@ -1004,6 +1034,10 @@ CamelMimePart *	e_content_editor_emit_ref_mime_part
 						(EContentEditor *editor,
 						 const gchar *uri);
 
+gboolean	e_content_editor_util_three_state_to_bool
+						(EThreeState value,
+						 const gchar *mail_key);
+
 G_END_DECLS
 
 #endif /* E_CONTENT_EDITOR_H */
